<?php
	/*
	 *
	 * 2003 - 2023 @ Yal Publicidad - yPanel
	 * www.yalpublicidad.com
	 * online@yalpublicidad.com
	 *
	 * formulario de modulo
	 */
	
	/* Autorizo acceso */
		defined('YPANEL_INI') or die( 'No dispones de acceso' );
		
	$sec	= ( isset( $_GET['sec'] ) ) ? $_GET['sec'] : false;
	$nivel	= ( isset( $_GET['nivel'] ) ) ? $_GET['nivel'] : 'asistente';
	
	if( $sec == 'reglas' ){
?>
		<form action="<?php echo com_base() ?>prcss.php" method="post">
			<input type="hidden" name="user" value="<?php echo com_obtReg( "usuario" ); ?>" >
			<input type="hidden" name="acc" value="privilegios" >
			
			<div align="right">
				<?php 
					echo com_boton( 'cancelar', etiqueta( 'b_volver', 'Volver' ) ) . ' ' .
						com_boton( 'editar', etiqueta( 'b_restablecer', 'Restablecer datos por defecto' ) ) . ' ' . 
						com_boton( 'guardar', NULL, true ); 
				?>
			</div>
			
			<hr>
			
			<div class="row">
				<div class="col-sm-12">
					<fieldset class="">
						<legend><?php echo etiqueta( 'legend_usuarios_3', 'Privilegio en paneles y extensiones' ) ?></legend>
						<?php echo reglas_u( com_obtReg( "usuario" ), $nivel ); ?>
					</fieldset>
				</div>
			</div>
			
			
		</form>
		
		<script>
			$_("#editar").onclick = function(){ 
				MsjBox.mostrar('Restableciendo...');
				$y.ajax({
						url: '<?php echo com_base() ?>prcss.php',
						metodo: 'POST',
						data: 'acc=res-priv&user=<?php echo com_obtReg( "usuario" ); ?>&n=<?php echo $nivel ?>',
						contenidoTipo: 'application/x-www-form-urlencoded',
						suceso: function(respuesta){ 
									if( respuesta == 1 ){
										 MsjBox.mostrar('Se restableció los valores correctamente');
										 setTimeout("location.reload();",800);
									}
									//MsjBox.mostrar(respuesta);
						}
				}); 
			}
		</script>
<?php
	}else{
		$disable	= ( com_obtReg( "usuario" ) == yPanel::usuario() ) ? true : false;
		$habilitado	= ( com_obtReg( 'bloqueado' ) == true ) ? 1 : 0;
?>
		<form action="<?php echo com_base() ?>prcss.php" method="post" id="frmUsr">
			<input type="hidden" name="post" value="<?php echo com_obtReg( "id", 0 ); ?>" >
			<input type="hidden" name="acc" value="usuario" >
			
			<div class="row">
				<div class="col-sm-8">
					<fieldset class="m-r-5">
						<legend><?php echo etiqueta( 'legend_usuarios_1', 'Datos de usuario' ) ?></legend>
							
							<div class="row m-b-10">
								<div class="col-sm-3"><label for="nombre"><?php echo etiqueta( 'e_nombre', 'Nombre' ) ?></label></div>
								<div class="col-sm-9"><input type="text" class="w-full" id="nombre" name="nombre" placeholder="Nombre" value="<?php echo com_obtReg( "nombre_usuario" ) ?>"></div>
							</div>
							<div class="row m-b-10">
								<div class="col-sm-3"><label for="email"><?php echo etiqueta( 'e_email', 'Correo electrónico' ) ?></label></div>
								<div class="col-sm-9"><input type="email" class="w-full" id="email" name="email" placeholder="Correo electrónico" value="<?php echo com_obtReg( "email" ) ?>" ></div>
							</div>
					</fieldset>
					
					<fieldset class="m-t-20 m-r-5">
							<div class="row m-b-10">
								<div class="col-sm-3"><label for="usuario"><?php echo etiqueta( 'e_usuario', 'Usuario' ) ?></label></div>
								<div class="col-sm-9"><input type="text" id="usuario" name="user" value="<?php echo com_obtReg( "usuario" ) ?>"></div>
							</div>
							<div class="row m-b-10">
								<div class="col-sm-3"><label for="pass"><?php echo etiqueta( 'e_password', 'Contraseña' ) ?></label></div>
								<div class="col-sm-9"><input type="password" id="pass" name="pass" placeholder="Contraseña"></div>
							</div>
							<div class="row m-b-10">
								<div class="col-sm-3"><label><?php echo etiqueta( 'e_habilitado', 'Habilitado' ) ?></label></div>
								<div class="col-sm-9"><?php echo com_btnToggle( 'habilitado', 1, $habilitado, $disable ); ?></div>
							</div>
							<div class="row m-b-10">
								<div class="col-sm-3"><label for="nivel"><?php echo etiqueta( 'e_nivel', 'Nivel' ) ?></label></div>
								<div class="col-sm-9"><select id="nivel" name="nivel"><?php echo nivel_lista( com_obtReg( "nivel" ) ) ?></select> <?php echo com_boton( 'badminrol', etiqueta( 'b_admin_rol', 'Administrar rol' ), false ) ?></div>
							</div>
					</fieldset>
				</div>
				
				<div class="col-sm-4">
					<fieldset class="">
						<legend><?php echo etiqueta( 'legend_usuarios_2', 'Configuración de cuenta' ) ?></legend>
						<div>
							<strong><?php echo etiqueta( 't_idioma', 'Idioma' ) ?></strong>
							<select name="lng"><?php echo idiomas_instalados( com_obtReg( "usuario" ) ) ?></select>
						</div>
						
						<div class="m-t-15">
							<strong><?php echo etiqueta( 't_zona_horaria', 'Zona horaria' ) ?></strong>
							<select name="utc"><?php echo utc( com_obtReg( "usuario" ) ) ?></select>
						</div>
					</fieldset>
				</div>
			</div>
			<hr>
			<div align="right">
				<?php echo com_boton( 'cancelar' ); ?> 
				<button name="guardar"><?php echo etiqueta( 'b_guardar', 'Guardar cambios' ) ; ?></button>
			</div>
		</form>
		
	
		<script>
			
			$_("#frmUsr").onsubmit = function(){
				if( this.nombre.value == '' ){
					this.nombre.focus();
					MsjBox.mostrar( '<?php echo etiqueta( 'msj_err_1', 'Por favor ingrese un nombre válido.' ) ?>' );
					return false
				}
				if( this.email.value == '' ){
					this.email.focus();
					MsjBox.mostrar( '<?php echo etiqueta( 'msj_err_2', 'Por favor ingrese un email válido.' ) ?>' );
					return false
				}
				if( this.user.value == '' ){
					this.user.focus();
					MsjBox.mostrar( '<?php echo etiqueta( 'msj_err_3', 'Por favor ingrese un usuario válido...' ) ?>' );
					return false
				}
				
				$y.ajax({
						url: this.action,
						metodo: this.method,
						data: $y.serialize(this),
						contenidoTipo: 'application/x-www-form-urlencoded',
						suceso: function(respuesta){ 
									if( respuesta == 1 ){
										 $_('#consola_msj').innerHTML = '<?php echo msg_error('El usuario se creó correctamente', 'fa-ckeck-circle', 'alert-success' ); ?>'; window.scrollTo( 0, 0 );
										 //setTimeout("window.history.back();",800);
										 location.href = '<?php echo post_link( 'usuarios' ); ?>';
									} if( respuesta == 3 ){
										 $_('#consola_msj').innerHTML = '<?php echo msg_error('El usuario ya existe.', 'fa-ckeck-circle', 'alert-warning' ); ?>'; window.scrollTo( 0, 0 );
									}
						}
				});
				
				return false;
			}
			
			$_("#badminrol").onclick = function(){ location.href='<?php echo post_link( 'usuarios', com_obtReg( "id" ), "acc=editar&sec=reglas&nivel=" ); ?>' + $_('#nivel').value; }
		</script>
		
<?php
	}
?>

		<script>
			$_("#cancelar").onclick = function(){ history.go(-1); }
		</script>